==> V02.97.zip: tweet_live-V02.97/web/fens2014-edito/config.php <==
<?php
$config = array(
    'tracking_keywords' => array('#edito13'),
    'hashtag'    => '#fens2014 #edito13',
   	'date'   => '19.06.2014',
   	'heure'   => '14h-18h',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Séminaire écritures numériques et éditorialisation",

	'abstract'   =>
"Séminaire &laquo;&nbsp;écritures numériques et éditorialisation&nbsp;&raquo;&nbsp;:<br />
<br/>le 19/06/2014 de 14h à 18h<br/>
@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",

   	'description'=>
"<p><b>Atelier d’étude : tendances et enjeux</b><br/>
L’écriture numérique remet en question
les fondements du modèle de
production et de circulation du savoir
qui caractérisait l’édition traditionnelle
papier.<br/>
Le séminaire Écritures numériques
et éditorialisation mène depuis 2011
une refléxion sur les impacts du
numérique sur la culture et la connaissances
à travers l’analyse des
pratiques, tendances et des technologies
émergentes d’écriture, de lecture,
d’édition et d’éditorialisation.<br/>
Cette séance du séminaire clôture la
saison 2013-2014 et sera l’occasion de
revenir sur les principales problématiques
de façon collégiale autour d’une
table. Sur le mode de l’atelier, il s’agira
de recueillir des pistes de recherche et
des propositions concrètes autour des
notions de support, d’annotation, de
traduction, d’algorithme.<br/>
L’atelier se voudra fortement participatif,
en interaction avec les invités et
le public.<br/>
Avec la présence annoncée de Milad
Doueihi, Louise Merzeau, Philippe
Aigrain, Marc Jahjah, Matteo Treleani,
Hadrien Gardeur, etc.</p>",
   	'link' => 'http://www.iri.centrepompidou.fr/evenement/futur-en-seine-2014/',
   	'islive'     => true,
   	'keywords'   => 'futur en seine, design, metadata, iri, séminaire, éditorialisation, écritures numériques, vérité, fiction',
   	'rep' => basename(__DIR__),
   	'partenaires'=>
"<a href='http://www.futur-en-seine.fr/' class='footerLink' target='_blank'>Futur en Seine 2013</a>
 | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
 | <a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a>
 | <a href='http://www.cite.umontreal.ca/' class='footerLink' target='_blank'>Centre de recherche Interdisciplinaire sur les Technologies Émergentes</a> | <a href='http://www.mshparisnord.fr/fr/' class='footerLink' target='_blank'>Maison des Sciences de l'Homme Paris Nord</a>
 | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels
    
 	'head_logo' => 'images/fens-pt.png', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

 	'archive_title' => "Séminaire écritures numériques et éditorialisation&nbsp;: FenS 2014",
 	'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a> au Centre Pompidou<br />le 19/06/2014 14h-18h',

    // After the event
	'metadata'    => "",
);

==> V04.028.zip: tweet_live-V04.028/web/fens2014-edito/config.php <==
<?php
$config = array(
    'tracking_keywords' => array('#edito13'),
    'hashtag'    => '#fens2014 #edito13',
   	'date'   => '19.06.2014',
   	'heure'   => '14h-18h',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Séminaire écritures numériques et éditorialisation",

	'abstract'   =>
"Séminaire &laquo;&nbsp;écritures numériques et éditorialisation&nbsp;&raquo;&nbsp;:<br />
<br/>le 19/06/2014 de 14h à 18h<br/>
@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",

   	'description'=>
"<p><b>Atelier d’étude : tendances et enjeux</b><br/>
L’écriture numérique remet en question
les fondements du modèle de
production et de circulation du savoir
qui caractérisait l’édition traditionnelle
papier.<br/>
Le séminaire Écritures numériques
et éditorialisation mène depuis 2011
une refléxion sur les impacts du
numérique sur la culture et la connaissances
à travers l’analyse des
pratiques, tendances et des technologies
émergentes d’écriture, de lecture,
d’édition et d’éditorialisation.<br/>
Cette séance du séminaire clôture la
saison 2013-2014 et sera l’occasion de
revenir sur les principales problématiques
de façon collégiale autour d’une
table. Sur le mode de l’atelier, il s’agira
de recueillir des pistes de recherche et
des propositions concrètes autour des
notions de support, d’annotation, de
traduction, d’algorithme.<br/>
L’atelier se voudra fortement participatif,
en interaction avec les invités et
le public.<br/>
Avec la présence annoncée de Milad
Doueihi, Louise Merzeau, Philippe
Aigrain, Marc Jahjah, Matteo Treleani,
Hadrien Gardeur, etc.</p>",
   	'link' => 'http://www.iri.centrepompidou.fr/evenement/futur-en-seine-2014/',
   	'islive'     => true,
   	'keywords'   => 'futur en seine, design, metadata, iri, séminaire, éditorialisation, écritures numériques, vérité, fiction',
   	'rep' => basename(__DIR__),
   	'partenaires'=>
"<a href='http://www.futur-en-seine.fr/' class='footerLink' target='_blank'>Futur en Seine 2013</a>
 | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
 | <a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a>
 | <a href='http://www.cite.umontreal.ca/' class='footerLink' target='_blank'>Centre de recherche Interdisciplinaire sur les Technologies Émergentes</a> | <a href='http://www.mshparisnord.fr/fr/' class='footerLink' target='_blank'>Maison des Sciences de l'Homme Paris Nord</a>
 | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels
    
 	'head_logo' => 'images/fens-pt.png', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

 	'archive_title' => "Séminaire écritures numériques et éditorialisation&nbsp;: FenS 2014",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br>le 19 juin 2014 au Centre Pompidou',

    // After the event
	'metadata'    => "c1a3e6fa-fac4-11e3-88b8-00145ea4a2be",
);
